@@ -1,3 +1,4 @@
+from abc import abstractmethod
 from dataclasses import dataclass
 from typing import List
 
@@ -9,9 +10,19 @@ class BlenderCollection:
     def blender_collection(self, bpy):
         if self._blender_collection is None:
             self._blender_collection = bpy.data.collections.new(self.name)
+
+            # Initialize a single blender object to this collection
             self._blender_collection.objects.link(self.blender_object(bpy))
         return self._blender_collection
 
+    @abstractmethod
+    def blender_object(self, bpy):
+        pass
+
+    @abstractmethod
+    def object_data(self, bpy):
+        pass
+
 
 @dataclass
 class BlenderObject(BlenderCollection):
@@ -23,8 +34,13 @@ class BlenderObject(BlenderCollection):
 
     def blender_object(self, bpy):
         if self._blender_object is None:
+            # This initializes the blender object and calls object_data() which should be overwritten by child class
             self._blender_object = bpy.data.objects.new(name=self.name, object_data=self.object_data(bpy))
         self._blender_object.location = self.xyz
         self._blender_object.rotation_mode = 'QUATERNION'
         self._blender_object.rotation_quaternion = self.quaternion
         return self._blender_object
+
+    @abstractmethod
+    def object_data(self, bpy):
+        pass
